@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  *
- * $Id: cpu_stats.c,v 1.17 2004/01/19 16:49:21 tdb Exp $
+ * $Id: cpu_stats.c,v 1.19 2004/02/16 14:55:32 tdb Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,7 +34,7 @@
 #if defined(LINUX) || defined(CYGWIN)
 #include <stdio.h>
 #endif
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 #include <sys/sysctl.h>
 #include <sys/dkstat.h>
 #endif
@@ -44,6 +44,11 @@
 #include <sys/sysctl.h>
 #include <sys/sched.h>
 #endif
+#ifdef OPENBSD
+#include <sys/param.h>
+#include <sys/sysctl.h>
+#include <sys/dkstat.h>
+#endif
 
 static cpu_states_t cpu_now;
 static int cpu_now_uninit=1;
@@ -59,7 +64,7 @@ cpu_states_t *get_cpu_totals(){
 	FILE *f;
 #endif
 #ifdef ALLBSD
-#ifndef FREEBSD
+#if defined(NETBSD) || defined(OPENBSD)
 	int mib[2];
 #endif
 #ifdef NETBSD
@@ -120,14 +125,18 @@ cpu_states_t *get_cpu_totals(){
 	cpu_now.total=cpu_now.user+cpu_now.nice+cpu_now.kernel+cpu_now.idle;
 #endif
 #ifdef ALLBSD
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 	size = sizeof cp_time;
 	if (sysctlbyname("kern.cp_time", &cp_time, &size, NULL, 0) < 0){
 		return NULL;
   	}
 #else
 	mib[0] = CTL_KERN;
+#ifdef NETBSD
 	mib[1] = KERN_CP_TIME;
+#else
+	mib[1] = KERN_CPTIME;
+#endif
 	size = sizeof cp_time;
 	if (sysctl(mib, 2, &cp_time, &size, NULL, 0) < 0) {
 		return NULL;
