@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: disk_stats.c,v 1.50 2004/01/21 23:46:54 ats Exp $
+ * $Id: disk_stats.c,v 1.53 2004/02/16 14:55:32 tdb Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -61,13 +61,13 @@
 #include <sys/ucred.h>
 #include <sys/mount.h>
 #endif
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 #include <sys/dkstat.h>
 #include <devstat.h>
 #define VALID_FS_TYPES {"hpfs", "msdosfs", "ntfs", "udf", "ext2fs", \
                         "ufs", "mfs"}
 #endif
-#ifdef NETBSD
+#if defined(NETBSD) || defined(OPENBSD)
 #include <sys/param.h>
 #include <sys/sysctl.h>
 #include <sys/disk.h>
@@ -349,7 +349,7 @@ diskio_stat_t *get_diskio_stats(int *entries){
 	time_t now;
 	const char *format;
 #endif
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 	static struct statinfo stats;
 	static int stats_init = 0;
 	int counter;
@@ -360,35 +360,89 @@ diskio_stat_t *get_diskio_stats(int *entries){
 #endif
 #ifdef NETBSD
 	struct disk_sysctl *stats;
+#endif
+#ifdef OPENBSD
+	int diskcount;
+	char *disknames, *name, *bufpp;
+	char **dk_name;
+	struct diskstats *stats;
+#endif
+#ifdef NETBSD
+#define MIBSIZE 3
+#endif
+#ifdef OPENBSD
+#define MIBSIZE 2
+#endif
+#if defined(NETBSD) || defined(OPENBSD)
 	int num_disks, i;
-	int mib[3];
+	int mib[MIBSIZE];
 	size_t size;
 #endif
 
 	num_diskio=0;
 
-#ifdef NETBSD
+#ifdef OPENBSD
 	mib[0] = CTL_HW;
-	mib[1] = HW_DISKSTATS;
-	mib[2] = sizeof(struct disk_sysctl);
+	mib[1] = HW_DISKCOUNT;
 
-	if (sysctl(mib, 3, NULL, &size, NULL, 0) < 0) {
+	size = sizeof(diskcount);
+	if (sysctl(mib, MIBSIZE, &diskcount, &size, NULL, 0) < 0) {
 		return NULL;
 	}
+
+	mib[0] = CTL_HW;
+	mib[1] = HW_DISKNAMES;
+
+	if (sysctl(mib, MIBSIZE, NULL, &size, NULL, 0) < 0) {
+		return NULL;
+	}
+
+	disknames = malloc(size);
+	if (disknames == NULL) {
+		return NULL;
+	}
+
+	if (sysctl(mib, MIBSIZE, disknames, &size, NULL, 0) < 0) {
+		return NULL;
+	}
+
+	dk_name = calloc(diskcount, sizeof(char *));
+	bufpp = disknames;
+	for (i = 0; i < diskcount && (name = strsep(&bufpp, ",")) != NULL; i++) {
+		dk_name[i] = name;
+	}
+#endif
+
+#if defined(NETBSD) || defined(OPENBSD)
+	mib[0] = CTL_HW;
+	mib[1] = HW_DISKSTATS;
+#ifdef NETBSD
+	mib[2] = sizeof(struct disk_sysctl);
+#endif
+
+	if (sysctl(mib, MIBSIZE, NULL, &size, NULL, 0) < 0) {
+		return NULL;
+	}
+
+#ifdef NETBSD
 	num_disks = size / sizeof(struct disk_sysctl);
+#else
+	num_disks = size / sizeof(struct diskstats);
+#endif
 
 	stats = malloc(size);
 	if (stats == NULL) {
 		return NULL;
 	}
 
-	if (sysctl(mib, 3, stats, &size, NULL, 0) < 0) {
+	if (sysctl(mib, MIBSIZE, stats, &size, NULL, 0) < 0) {
 		return NULL;
 	}
 
 	for (i = 0; i < num_disks; i++) {
 		u_int64_t rbytes, wbytes;
 
+#ifdef NETBSD
 #ifdef HAVE_DK_RBYTES
 		rbytes = stats[i].dk_rbytes;
 		wbytes = stats[i].dk_wbytes;
@@ -396,6 +450,9 @@ diskio_stat_t *get_diskio_stats(int *entries){
 		/* Before 1.7, NetBSD merged reads and writes. */
 		rbytes = wbytes = stats[i].dk_bytes;
 #endif
+#else
+		rbytes = wbytes = stats[i].ds_bytes;
+#endif
 
 		/* Don't keep stats for disks that have never been used. */
 		if (rbytes == 0 && wbytes == 0) {
@@ -415,16 +472,24 @@ diskio_stat_t *get_diskio_stats(int *entries){
 		if (diskio_stats_ptr->disk_name != NULL) {
 			free(diskio_stats_ptr->disk_name);
 		}
+#ifdef NETBSD
 		diskio_stats_ptr->disk_name = strdup(stats[i].dk_name);
+#else
+		diskio_stats_ptr->disk_name = strdup(dk_name[i]);
+#endif
 		diskio_stats_ptr->systime = time(NULL);
 	
 		num_diskio++;	
 	}
 
 	free(stats);
+#ifdef OPENBSD
+	free(dk_name);
+	free(disknames);
+#endif
 #endif
 
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 	if (!stats_init) {
 		stats.dinfo=malloc(sizeof(struct devinfo));
 		if(stats.dinfo==NULL) return NULL;
