@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: os_info.c,v 1.13 2004/01/19 16:49:21 tdb Exp $
+ * $Id: os_info.c,v 1.14 2004/02/16 14:55:32 tdb Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,7 +36,7 @@
 #include <stdio.h>
 #endif
 #ifdef ALLBSD
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 #include <sys/types.h>
 #include <sys/sysctl.h>
 #else
