@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: page_stats.c,v 1.14 2004/01/19 16:49:21 tdb Exp $
+ * $Id: page_stats.c,v 1.17 2004/02/16 14:55:32 tdb Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,10 +37,14 @@
 #include <stdio.h>
 #include <string.h>
 #endif
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 #include <sys/types.h>
 #include <sys/sysctl.h>
 #endif
+#if defined(NETBSD) || defined(OPENBSD)
+#include <sys/param.h>
+#include <uvm/uvm.h>
+#endif
 
 static page_stat_t page_stats;
 static int page_stats_uninit=1;
@@ -55,10 +59,10 @@ page_stat_t *get_page_stats(){
 	FILE *f;
 	char *line_ptr;
 #endif
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 	size_t size;
 #endif
-#ifdef NETBSD
+#if defined(NETBSD) || defined(OPENBSD)
 	struct uvmexp *uvm;
 #endif
 
@@ -115,7 +119,7 @@ page_stat_t *get_page_stats(){
 		return NULL;
 	}
 #endif
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(DFBSD)
 	size = sizeof page_stats.pages_pagein;
         if (sysctlbyname("vm.stats.vm.v_swappgsin", &page_stats.pages_pagein, &size, NULL, 0) < 0){
                 return NULL;
@@ -125,10 +129,11 @@ page_stat_t *get_page_stats(){
                 return NULL;
         }
 #endif
-#ifdef NETBSD
+#if defined(NETBSD) || defined(OPENBSD)
 	if ((uvm = get_uvmexp()) == NULL) {
 		return NULL;
 	}
+
 	page_stats.pages_pagein = uvm->pgswapin;
 	page_stats.pages_pageout = uvm->pgswapout;
 #endif
