@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: tools.c,v 1.27 2004/02/10 16:23:07 pajs Exp $
+ * $Id: tools.c,v 1.31 2004/02/16 14:55:32 tdb Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,10 +33,14 @@
 #include <regex.h>
 #ifdef ALLBSD
 #include <fcntl.h>
+#endif
+#if defined(FREEBSD) || defined(DFBSD)
 #include <kvm.h>
 #endif
-#ifdef NETBSD
+#if defined(NETBSD) || defined(OPENBSD)
 #include <uvm/uvm_extern.h>
+#include <sys/param.h>
+#include <sys/sysctl.h>
 #endif
 
 #include "tools.h"
@@ -416,7 +420,7 @@ long long get_ll_match(char *line, regmatch_t *match){
 	return num;
 }
 
-#ifdef ALLBSD
+#if defined(FREEBSD) || defined(DFBSD)
 kvm_t *get_kvm() {
 	static kvm_t *kvmd = NULL;
 
@@ -429,48 +433,39 @@ kvm_t *get_kvm() {
 }
 #endif
 
-#ifdef NETBSD
+#if defined(NETBSD) || defined(OPENBSD)
 struct uvmexp *get_uvmexp() {
-	static u_long addr = 0;
-	static struct uvmexp uvm;
-	kvm_t *kvmd = get_kvm();
+	int mib[2];
+	size_t size;
+	static struct uvmexp *uvm = NULL;
 
-	if (kvmd == NULL) {
+	mib[0] = CTL_VM;
+	mib[1] = VM_UVMEXP;
+
+	if (sysctl(mib, 2, NULL, &size, NULL, 0) < 0) {
 		return NULL;
 	}
 
-	if (addr == 0) {
-		struct nlist symbols[] = {
-			{ "_uvmexp" },
-			{ NULL }
-		};
-
-		if (kvm_nlist(kvmd, symbols) != 0) {
-			return NULL;
-		}
-		addr = symbols[0].n_value;
-	}
-
-	if (kvm_read(kvmd, addr, &uvm, sizeof uvm) != sizeof uvm) {
+	uvm = realloc(uvm, size);
+	if (uvm == NULL) {
 		return NULL;
 	}
-	return &uvm;
+
+	if (sysctl(mib, 2, uvm, &size, NULL, 0) < 0) {
+		return NULL;
+	}
+
+	return uvm;
 }
 #endif
 
 int statgrab_init(){
-#ifdef ALLBSD 
+#if defined(FREEBSD) || defined(DFBSD)
 	{ 
 		kvm_t *kvmd = get_kvm(); 
 		if (kvmd == NULL) return 1;
 	}
 #endif
-#ifdef NETBSD
-	{
-		struct uvmexp *uvm = get_uvmexp();
-		if (uvm == NULL) return 1;
-	}
-#endif
 #ifdef SOLARIS
 	/* On solaris 7, this will fail if you are not root. But, everything
 	 * will still work, just no disk mappings. So we will ignore the exit
