@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: user_stats.c,v 1.17 2004/01/21 14:44:22 ats Exp $
+ * $Id: user_stats.c,v 1.19 2004/02/16 14:55:32 tdb Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,9 +32,12 @@
 #ifdef ALLBSD
 #include <sys/types.h>
 #endif
-#ifdef NETBSD
+#if defined(NETBSD) || defined(OPENBSD)
 #include <limits.h>
 #endif
+#ifdef OPENBSD
+#include <sys/param.h>
+#endif
 #include <utmp.h>
 #ifdef CYGWIN
 #include <sys/unistd.h>
@@ -43,10 +46,10 @@
 #ifdef SOLARIS
 #define MAX_LOGIN_NAME_SIZE 8
 #endif
-#if defined(LINUX) || defined(FREEBSD)
+#if defined(LINUX) || defined(FREEBSD) || defined(DFBSD)
 #define MAX_LOGIN_NAME_SIZE UT_NAMESIZE
 #endif
-#ifdef NETBSD
+#if defined(NETBSD) || defined(OPENBSD)
 #define MAX_LOGIN_NAME_SIZE _POSIX_LOGIN_NAME_MAX
 #endif
 #if defined(CYGWIN)
