@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: statgrab.c,v 1.17 2004/01/19 16:49:23 tdb Exp $
+ * $Id: statgrab.c,v 1.22 2004/03/06 22:34:36 ats Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,7 +37,9 @@ typedef enum {
 	FLOAT,
 	DOUBLE,
 	STRING,
-	INT
+	INT,
+	BOOL,
+	DUPLEX
 } stat_type;
 
 typedef enum {
@@ -348,6 +350,7 @@ void populate_proc() {
 void populate_net() {
 	int n, i;
 	network_stat_t *net;
+	network_iface_stat_t *iface;
 
 	net = use_diffs ? get_network_stats_diff(&n) : get_network_stats(&n);
 	if (net != NULL) {
@@ -360,10 +363,34 @@ void populate_net() {
 			         "net", name, "tx", NULL);
 			add_stat(LONG_LONG, &net[i].rx,
 			         "net", name, "rx", NULL);
+			add_stat(LONG_LONG, &net[i].ipackets,
+			         "net", name, "ipackets", NULL);
+			add_stat(LONG_LONG, &net[i].opackets,
+			         "net", name, "opackets", NULL);
+			add_stat(LONG_LONG, &net[i].ierrors,
+			         "net", name, "ierrors", NULL);
+			add_stat(LONG_LONG, &net[i].oerrors,
+			         "net", name, "oerrors", NULL);
+			add_stat(LONG_LONG, &net[i].collisions,
+			         "net", name, "collisions", NULL);
 			add_stat(TIME_T, &net[i].systime,
 			         "net", name, "systime", NULL);
 		}
 	}
+
+	iface = get_network_iface_stats(&n);
+	if (iface != NULL) {
+		for (i = 0; i < n; i++) {
+			const char *name = iface[i].interface_name;
+
+			add_stat(INT, &iface[i].speed,
+			         "net", name, "speed", NULL);
+			add_stat(BOOL, &iface[i].up,
+			         "net", name, "up", NULL);
+			add_stat(DUPLEX, &iface[i].dup,
+			         "net", name, "duplex", NULL);
+		}
+	}
 }
 
 void populate_page() {
@@ -432,7 +459,8 @@ void get_stats() {
 			t->populate();
 	}
 
-	qsort(stats, num_stats, sizeof *stats, stats_compare);
+	if (stats != NULL)
+		qsort(stats, num_stats, sizeof *stats, stats_compare);
 }
 
 /* Print the value of a stat. */
@@ -460,6 +488,22 @@ void print_stat_value(const stat *s) {
 	case INT:
 		printf("%d", *(int *)v);
 		break;
+	case BOOL:
+		printf("%s", *(int *)v ? "true" : "false");
+		break;
+	case DUPLEX:
+		switch (*(statgrab_duplex *) v) {
+		case FULL_DUPLEX:
+			printf("full");
+			break;
+		case HALF_DUPLEX:
+			printf("half");
+			break;
+		default:
+			printf("unknown");
+			break;
+		}
+		break;
 	}
 }
 
@@ -502,8 +546,15 @@ void print_stats(int argc, char **argv) {
 			else
 				compare = stats_compare;
 
-			s = (const stat *)bsearch(&key, stats, num_stats,
-			                          sizeof *stats, compare);
+			if (stats == NULL) {
+				s = NULL;
+			} else {
+				s = (const stat *)bsearch(&key, stats,
+				                          num_stats,
+				                          sizeof *stats,
+				                          compare);
+			}
+
 			if (s == NULL) {
 				printf("Unknown stat %s\n", name);
 				continue;
